@@ -1,8 +1,11 @@
-from kappadata.datasets.kd_wrapper import KDWrapper
-from kappadata.transforms.base.kd_transform import KDTransform
-
 from dataclasses import dataclass
 
+import numpy as np
+
+from kappadata.datasets.kd_wrapper import KDWrapper
+from kappadata.transforms import KDTransform, KDComposeTransform, KDStochasticTransform
+
+
 @dataclass
 class MultiViewConfig:
     n_views: int
@@ -10,8 +13,8 @@ class MultiViewConfig:
 
 
 class MultiViewWrapper(KDWrapper):
-    def __init__(self, configs, **kwargs):
-        super().__init__(**kwargs)
+    def __init__(self, dataset, configs, seed=None):
+        super().__init__(dataset=dataset)
         assert isinstance(configs, list)
         # copy to not alter the original list
         configs = [*configs]
@@ -27,13 +30,19 @@ class MultiViewWrapper(KDWrapper):
 
         self.transform_configs = configs
         self.n_views = sum(config.n_views for config in configs)
+        self.seed = seed
 
     def getitem_x(self, idx, ctx=None):
         sample = self.dataset.getitem_x(idx)
-
         x = []
-        counter = 0
+        i = 0
         for config in self.transform_configs:
+            # set rng of transforms
+            if self.seed is not None:
+                rng = np.random.default_rng(seed=self.seed + idx)
+                if isinstance(config.transform, (KDComposeTransform, KDStochasticTransform)):
+                    config.transform.set_rng(rng)
+            # sample views
             for _ in range(config.n_views):
                 view_ctx = {}
                 if isinstance(config.transform, KDTransform):
@@ -42,6 +51,11 @@ class MultiViewWrapper(KDWrapper):
                     view = config.transform(sample)
                 x.append(view)
                 if ctx is not None:
-                    ctx[f"view{counter}"] = view_ctx
-                    counter += 1
+                    ctx[f"view{i}"] = view_ctx
+                    i += 1
         return x
+
+    def worker_init_fn(self, rank, **kwargs):
+        for config in self.transform_configs:
+            if isinstance(config.transform, KDTransform):
+                config.transform.worker_init_fn(rank, **kwargs)
